summaryrefslogtreecommitdiff
path: root/gcc/function.h
diff options
context:
space:
mode:
authorNathan Sidwell <nathan@gcc.gnu.org>2003-06-16 08:27:05 +0000
committerNathan Sidwell <nathan@gcc.gnu.org>2003-06-16 08:27:05 +0000
commitfd3acbb3a2c176dc658f2b957c3693dfebb2ae7e (patch)
tree2b5cb543169ef70477d25bcc0683bd89eb4851a2 /gcc/function.h
parent695a94b30aef2dbf9d30e96d02c8fdfa5d99c3eb (diff)
downloadgcc-fd3acbb3a2c176dc658f2b957c3693dfebb2ae7e.tar.gz
function.h (struct emit_status): Remove x_last_linenum, x_last_filename.
* function.h (struct emit_status): Remove x_last_linenum, x_last_filename. Add x_last_location. * rtl.h: #include "input.h". (NOTE_DATA): New. * cfglayout.c (duplicate_insn_chain): Use emit_line_note for line number notes. * emit-rtl.c (last_linenum, last_filename): Remove. (last_location): New. (emit_line_note_after): LINE must always be >= 0. (emit_line_note): Likewise. Check not duplicate here... (emit_note): ... rather than here. (emit_line_note_force, force_next_line_note, init_emit): Adjust. * integrate.c (expand_inline_function): Use emit_line_note for line number notes. (copy_insn_list): Likewise. * unroll.c (copy_loop_body): Likewise. * Makefile.in (RTL_H): Add input.h. From-SVN: r68002
Diffstat (limited to 'gcc/function.h')
-rw-r--r--gcc/function.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/gcc/function.h b/gcc/function.h
index f9db14c3cbc..24bebc1982e 100644
--- a/gcc/function.h
+++ b/gcc/function.h
@@ -83,10 +83,9 @@ struct emit_status GTY(())
Reset to 1 for each function compiled. */
int x_cur_insn_uid;
/* Line number and source file of the last line-number NOTE emitted.
This is used to avoid generating duplicates. */
- int x_last_linenum;
- const char *x_last_filename;
+ location_t x_last_location;
/* The length of the regno_pointer_align, regno_decl, and x_regno_reg_rtx
vectors. Since these vectors are needed during the expansion phase when
@@ -83,10 +83,9 @@ struct emit_status GTY(())
Reset to 1 for each function compiled. */
int x_cur_insn_uid;
- /* Line number and source file of the last line-number NOTE emitted.
+ /* Location the last line-number NOTE emitted.
This is used to avoid generating duplicates. */